@@ -20,17 +20,16 @@
 #include "fileview.h"
 
 #include <QFileInfo>
+#include <QFileDialog>
 #include <QHeaderView>
 #include <QItemSelectionModel>
 #include <QMenu>
 #include <QSortFilterProxyModel>
 
 #include <KConfigGroup>
-#include <KFileDialog>
 #include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KMimeType>
 #include <KRun>
 
 #include <util/bitset.h>
@@ -40,6 +39,7 @@
 #include <interfaces/torrentfileinterface.h>
 #include <util/log.h>
 #include <util/timer.h>
+#include <KSharedConfig>
 #include "iwfiletreemodel.h"
 #include "iwfilelistmodel.h"
 	
@@ -277,8 +277,7 @@ namespace kt
 			QModelIndexList sel = selectionModel()->selectedRows();
 			QMap<bt::TorrentFileInterface*,QString> moves;
 			
-			QString dir = KFileDialog::getExistingDirectory(QUrl("kfiledialog:///saveTorrentData"),
-					this,i18n("Select a directory to move the data to."));
+			QString dir = QFileDialog::getExistingDirectory(this, i18n("Select a directory to move the data to"));
 			if (dir.isNull())
 				return;
 			
@@ -298,8 +297,7 @@ namespace kt
 		}
 		else
 		{
-			QString dir = KFileDialog::getExistingDirectory(QUrl("kfiledialog:///saveTorrentData"),
-					this,i18n("Select a directory to move the data to."));
+			QString dir = QFileDialog::getExistingDirectory(this, i18n("Select a directory to move the data to"));
 			if (dir.isNull())
 				return;
 		
