@@ -35,8 +35,8 @@ class MirrorAddDlg : public QDialog
     Q_OBJECT
 
     public:
-        explicit MirrorAddDlg(MirrorModel *model, QWidget *parent = nullptr, Qt::WFlags flags = 0);
-        explicit MirrorAddDlg(MirrorModel *model, QSortFilterProxyModel *countryModel, QWidget *parent = nullptr, Qt::WFlags flags = 0);
+        explicit MirrorAddDlg(MirrorModel *model, QWidget *parent = nullptr, Qt::WindowFlags flags = {});
+        explicit MirrorAddDlg(MirrorModel *model, QSortFilterProxyModel *countryModel, QWidget *parent = nullptr, Qt::WindowFlags flags = {});
         
         virtual QSize sizeHint() const override;
 
